starcluster.webtools.BackgroundBrowser

Package starcluster :: Module webtools :: Class BackgroundBrowser |
[hide private]
[frames] | no frames]

# Class BackgroundBrowser

source code

Class for all browsers which are to be started in the background.

Instance Methods | [hide private]
open(self, url, new=0, autoraise=1) | source code
Inherited from `webbrowser.GenericBrowser`: `__init__` Inherited from `webbrowser.BaseBrowser`: `open_new`, `open_new_tab` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `webbrowser.BaseBrowser`: `args`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### open(self, url, new=0, autoraise=1) | source code
Overrides: webbrowser.BaseBrowser.open